@@ -5,6 +5,9 @@
 struct PGrnBuffers
 {
 	grn_obj general;
+	grn_obj generalElement;
+	grn_obj cast;
+	grn_obj castElement;
 	grn_obj path;
 	grn_obj keyword;
 	grn_obj pattern;
@@ -12,8 +15,9 @@ struct PGrnBuffers
 	grn_obj score;
 	grn_obj sourceIDs;
 	grn_obj tokenizer;
-	grn_obj normalizer;
+	grn_obj normalizers;
 	grn_obj tokenFilters;
+	grn_obj plugins;
 	grn_obj jsonbValueKeys;
 	grn_obj jsonbTokenStack;
 	grn_obj text;
@@ -31,10 +35,9 @@ struct PGrnBuffers
 	grn_obj head;
 	grn_obj body;
 	grn_obj foot;
-	grn_obj inspect;
+	grn_obj walBuffer;
 };
 
-extern grn_ctx PGrnContext;
 extern struct PGrnBuffers PGrnBuffers;
 extern int PGrnMatchEscalationThreshold;
 
